# -*- coding: utf-8 -*-

from __future__ import absolute_import, print_function, division

from earthy.nltk_wrappers import download, sent_tokenize, word_tokenize
from earthy.nltk_wrappers import pos_tag, pos_tag_sents
